@@ -10,9 +10,6 @@ use Moose;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Class;
@@ -28,7 +25,7 @@ Moose::Exporter->setup_import_methods(
 
 extends 'W3C::SOAP::Parser';
 
-our $VERSION     = version->new('0.06');
+our $VERSION = version->new('0.07');
 
 has '+document' => (
     isa      => 'W3C::SOAP::WSDL::Document',
@@ -218,7 +215,7 @@ libraries to access the Web Service defined.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Parser version 0.06.
+This documentation refers to W3C::SOAP::WSDL::Parser version 0.07.
 
 =head1 SYNOPSIS
 
