@@ -18,13 +18,13 @@ use English qw/ -no_match_vars /;
 
 extends 'W3C::SOAP::XSD::Document::Node';
 
-our $VERSION     = version->new('0.06');
+our $VERSION     = version->new('0.07');
 
 has documentation => (
     is     => 'rw',
     isa    => 'Str',
     builder => '_documentation',
-    lazy_build => 1,
+    lazy => 1,
 );
 
 sub _documentation {
@@ -49,7 +49,7 @@ W3C::SOAP::XSD::Document::Type - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::Type version 0.06.
+This documentation refers to W3C::SOAP::XSD::Document::Type version 0.07.
 
 
 =head1 SYNOPSIS
